# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/extensions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/extensions.proto',
  package='extension',
  syntax='proto3',
  serialized_options=b'\n\035org.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v5/go/extension',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1evoltha_protos/extensions.proto\x12\textension\x1a\x1evoltha_protos/ext_config.proto\x1a\x1bgoogle/protobuf/empty.proto\"L\n\x08ValueSet\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x0c\x61larm_config\x18\x02 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x42\x07\n\x05value\",\n\tValueType\"\x1f\n\x04Type\x12\t\n\x05\x45MPTY\x10\x00\x12\x0c\n\x08\x44ISTANCE\x10\x01\"F\n\x0eValueSpecifier\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0e\x32\x19.extension.ValueType.Type\"Q\n\x0cReturnValues\x12\x0b\n\x03Set\x18\x01 \x01(\r\x12\x13\n\x0bUnsupported\x18\x02 \x01(\r\x12\r\n\x05\x45rror\x18\x03 \x01(\r\x12\x10\n\x08\x44istance\x18\x04 \x01(\r\")\n\x12GetDistanceRequest\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\"\'\n\x13GetDistanceResponse\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\"(\n\x14GetOnuUniInfoRequest\x12\x10\n\x08uniIndex\x18\x01 \x01(\r\"\xc1\x04\n\x15GetOnuUniInfoResponse\x12\x46\n\x08\x61\x64mState\x18\x01 \x01(\x0e\x32\x34.extension.GetOnuUniInfoResponse.AdministrativeState\x12\x44\n\toperState\x18\x02 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.OperationalState\x12\x44\n\tconfigInd\x18\x03 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.ConfigurationInd\"\xc2\x01\n\x10\x43onfigurationInd\x12\n\n\x06UNKOWN\x10\x00\x12\x12\n\x0eTEN_BASE_T_FDX\x10\x01\x12\x16\n\x12HUNDRED_BASE_T_FDX\x10\x02\x12\x18\n\x14GIGABIT_ETHERNET_FDX\x10\x03\x12\x16\n\x12TEN_G_ETHERNET_FDX\x10\x04\x12\x12\n\x0eTEN_BASE_T_HDX\x10\x05\x12\x16\n\x12HUNDRED_BASE_T_HDX\x10\x06\x12\x18\n\x14GIGABIT_ETHERNET_HDX\x10\x07\"G\n\x13\x41\x64ministrativeState\x12\x16\n\x12\x41\x44MSTATE_UNDEFINED\x10\x00\x12\n\n\x06LOCKED\x10\x01\x12\x0c\n\x08UNLOCKED\x10\x02\"F\n\x10OperationalState\x12\x17\n\x13OPERSTATE_UNDEFINED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xa5\x01\n\x12GetOltPortCounters\x12\x0e\n\x06portNo\x18\x01 \x01(\r\x12\x38\n\x08portType\x18\x02 \x01(\x0e\x32&.extension.GetOltPortCounters.PortType\"E\n\x08PortType\x12\x10\n\x0cPort_UNKNOWN\x10\x00\x12\x15\n\x11Port_ETHERNET_NNI\x10\x01\x12\x10\n\x0cPort_PON_OLT\x10\x02\"\xa4\x02\n\x1aGetOltPortCountersResponse\x12\x0f\n\x07txBytes\x18\x01 \x01(\x04\x12\x0f\n\x07rxBytes\x18\x02 \x01(\x04\x12\x11\n\ttxPackets\x18\x03 \x01(\x04\x12\x11\n\trxPackets\x18\x04 \x01(\x04\x12\x16\n\x0etxErrorPackets\x18\x05 \x01(\x04\x12\x16\n\x0erxErrorPackets\x18\x06 \x01(\x04\x12\x16\n\x0etxBcastPackets\x18\x07 \x01(\x04\x12\x16\n\x0erxBcastPackets\x18\x08 \x01(\x04\x12\x16\n\x0etxUcastPackets\x18\t \x01(\x04\x12\x16\n\x0erxUcastPackets\x18\n \x01(\x04\x12\x16\n\x0etxMcastPackets\x18\x0b \x01(\x04\x12\x16\n\x0erxMcastPackets\x18\x0c \x01(\x04\"=\n\x14GetOnuPonOpticalInfo\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\xa5\x01\n\x1cGetOnuPonOpticalInfoResponse\x12\x18\n\x10powerFeedVoltage\x18\x01 \x01(\x02\x12\x1c\n\x14receivedOpticalPower\x18\x02 \x01(\x02\x12\x1e\n\x16meanOpticalLaunchPower\x18\x03 \x01(\x02\x12\x18\n\x10laserBiasCurrent\x18\x04 \x01(\x02\x12\x13\n\x0btemperature\x18\x05 \x01(\x02\"\xa4\x01\n\x1fGetOnuEthernetBridgePortHistory\x12G\n\tdirection\x18\x01 \x01(\x0e\x32\x34.extension.GetOnuEthernetBridgePortHistory.Direction\"8\n\tDirection\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08UPSTREAM\x10\x01\x12\x0e\n\nDOWNSTREAM\x10\x02\"\x96\x03\n\'GetOnuEthernetBridgePortHistoryResponse\x12\x12\n\ndropEvents\x18\x01 \x01(\r\x12\x0e\n\x06octets\x18\x02 \x01(\r\x12\x0f\n\x07packets\x18\x03 \x01(\r\x12\x18\n\x10\x62roadcastPackets\x18\x04 \x01(\r\x12\x18\n\x10multicastPackets\x18\x05 \x01(\r\x12\x19\n\x11\x63rcErroredPackets\x18\x06 \x01(\r\x12\x18\n\x10undersizePackets\x18\x07 \x01(\r\x12\x17\n\x0foversizePackets\x18\x08 \x01(\r\x12\x17\n\x0fpackets64octets\x18\t \x01(\r\x12\x1c\n\x14packets65To127octets\x18\n \x01(\r\x12\x1d\n\x15packets128To255Octets\x18\x0b \x01(\r\x12\x1d\n\x15packets256To511octets\x18\x0c \x01(\r\x12\x1e\n\x16packets512To1023octets\x18\r \x01(\r\x12\x1f\n\x17packets1024To1518octets\x18\x0e \x01(\r\"9\n\x10GetOnuFecHistory\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\x9a\x01\n\x18GetOnuFecHistoryResponse\x12\x16\n\x0e\x63orrectedBytes\x18\x01 \x01(\r\x12\x1a\n\x12\x63orrectedCodeWords\x18\x02 \x01(\r\x12\x12\n\nfecSeconds\x18\x03 \x01(\r\x12\x16\n\x0etotalCodeWords\x18\x04 \x01(\r\x12\x1e\n\x16uncorrectableCodeWords\x18\x05 \x01(\r\"8\n\x15GetOnuCountersRequest\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"o\n%GetOmciEthernetFrameExtendedPmRequest\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\x12\x12\n\x08uniIndex\x18\x02 \x01(\rH\x00\x12\r\n\x05reset\x18\x03 \x01(\x08\x42\x0e\n\x0cis_uni_index\"4\n\x11GetRxPowerRequest\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"\xeb\t\n\x16GetOnuCountersResponse\x12\x11\n\x07intf_id\x18\x01 \x01(\x07H\x00\x12\x10\n\x06onu_id\x18\x02 \x01(\x07H\x01\x12\x18\n\x0epositive_drift\x18\x03 \x01(\x06H\x02\x12\x18\n\x0enegative_drift\x18\x04 \x01(\x06H\x03\x12\"\n\x18\x64\x65limiter_miss_detection\x18\x05 \x01(\x06H\x04\x12\x14\n\nbip_errors\x18\x06 \x01(\x06H\x05\x12\x13\n\tbip_units\x18\x07 \x01(\x06H\x06\x12\x1f\n\x15\x66\x65\x63_corrected_symbols\x18\x08 \x01(\x06H\x07\x12!\n\x17\x66\x65\x63_codewords_corrected\x18\t \x01(\x06H\x08\x12%\n\x1b\x66\x65\x63_codewords_uncorrectable\x18\n \x01(\x06H\t\x12\x17\n\rfec_codewords\x18\x0b \x01(\x06H\n\x12\x1d\n\x13\x66\x65\x63_corrected_units\x18\x0c \x01(\x06H\x0b\x12\x19\n\x0fxgem_key_errors\x18\r \x01(\x06H\x0c\x12\x13\n\txgem_loss\x18\x0e \x01(\x06H\r\x12\x19\n\x0frx_ploams_error\x18\x0f \x01(\x06H\x0e\x12\x1c\n\x12rx_ploams_non_idle\x18\x10 \x01(\x06H\x0f\x12\x11\n\x07rx_omci\x18\x11 \x01(\x06H\x10\x12\x11\n\x07tx_omci\x18\x12 \x01(\x06H\x11\x12#\n\x19rx_omci_packets_crc_error\x18\x13 \x01(\x06H\x12\x12\x12\n\x08rx_bytes\x18\x14 \x01(\x06H\x13\x12\x14\n\nrx_packets\x18\x15 \x01(\x06H\x14\x12\x12\n\x08tx_bytes\x18\x16 \x01(\x06H\x15\x12\x14\n\ntx_packets\x18\x17 \x01(\x06H\x16\x12\x16\n\x0c\x62\x65r_reported\x18\x18 \x01(\x06H\x17\x12\x15\n\x0blcdg_errors\x18\x19 \x01(\x06H\x18\x12\x14\n\nrdi_errors\x18\x1a \x01(\x06H\x19\x12\x13\n\ttimestamp\x18\x1b \x01(\x07H\x1a\x42\x0c\n\nis_intf_idB\x0b\n\tis_onu_idB\x13\n\x11is_positive_driftB\x13\n\x11is_negative_driftB\x1d\n\x1bis_delimiter_miss_detectionB\x0f\n\ris_bip_errorsB\x0e\n\x0cis_bip_unitsB\x1a\n\x18is_fec_corrected_symbolsB\x1c\n\x1ais_fec_codewords_correctedB \n\x1eis_fec_codewords_uncorrectableB\x12\n\x10is_fec_codewordsB\x18\n\x16is_fec_corrected_unitsB\x14\n\x12is_xgem_key_errorsB\x0e\n\x0cis_xgem_lossB\x14\n\x12is_rx_ploams_errorB\x17\n\x15is_rx_ploams_non_idleB\x0c\n\nis_rx_omciB\x0c\n\nis_tx_omciB\x1e\n\x1cis_rx_omci_packets_crc_errorB\r\n\x0bis_rx_bytesB\x0f\n\ris_rx_packetsB\r\n\x0bis_tx_bytesB\x0f\n\ris_tx_packetsB\x11\n\x0fis_ber_reportedB\x10\n\x0eis_lcdg_errorsB\x0f\n\ris_rdi_errorsB\x0e\n\x0cis_timestamp\"\x9b\x03\n\x1bOmciEthernetFrameExtendedPm\x12\x13\n\x0b\x64rop_events\x18\x01 \x01(\x06\x12\x0e\n\x06octets\x18\x02 \x01(\x06\x12\x0e\n\x06\x66rames\x18\x03 \x01(\x06\x12\x18\n\x10\x62roadcast_frames\x18\x04 \x01(\x06\x12\x18\n\x10multicast_frames\x18\x05 \x01(\x06\x12\x1a\n\x12\x63rc_errored_frames\x18\x06 \x01(\x06\x12\x18\n\x10undersize_frames\x18\x07 \x01(\x06\x12\x17\n\x0foversize_frames\x18\x08 \x01(\x06\x12\x18\n\x10\x66rames_64_octets\x18\t \x01(\x06\x12\x1f\n\x17\x66rames_65_to_127_octets\x18\n \x01(\x06\x12 \n\x18\x66rames_128_to_255_octets\x18\x0b \x01(\x06\x12 \n\x18\x66rames_256_to_511_octets\x18\x0c \x01(\x06\x12!\n\x19\x66rames_512_to_1023_octets\x18\r \x01(\x06\x12\"\n\x1a\x66rames_1024_to_1518_octets\x18\x0e \x01(\x06\"\xba\x02\n&GetOmciEthernetFrameExtendedPmResponse\x12\x38\n\x08upstream\x18\x01 \x01(\x0b\x32&.extension.OmciEthernetFrameExtendedPm\x12:\n\ndownstream\x18\x02 \x01(\x0b\x32&.extension.OmciEthernetFrameExtendedPm\x12h\n&omci_ethernet_frame_extended_pm_format\x18\x03 \x01(\x0e\x32\x38.extension.GetOmciEthernetFrameExtendedPmResponse.Format\"0\n\x06\x46ormat\x12\x12\n\x0eTHIRTY_TWO_BIT\x10\x00\x12\x12\n\x0eSIXTY_FOUR_BIT\x10\x01\"l\n\x12GetRxPowerResponse\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61il_reason\x18\x04 \x01(\t\x12\x10\n\x08rx_power\x18\x05 \x01(\x01\"\x9a\x04\n\x0fGetValueRequest\x12\x31\n\x08\x64istance\x18\x01 \x01(\x0b\x32\x1d.extension.GetDistanceRequestH\x00\x12\x32\n\x07uniInfo\x18\x02 \x01(\x0b\x32\x1f.extension.GetOnuUniInfoRequestH\x00\x12\x34\n\x0boltPortInfo\x18\x03 \x01(\x0b\x32\x1d.extension.GetOltPortCountersH\x00\x12\x39\n\x0eonuOpticalInfo\x18\x04 \x01(\x0b\x32\x1f.extension.GetOnuPonOpticalInfoH\x00\x12\x43\n\rethBridgePort\x18\x05 \x01(\x0b\x32*.extension.GetOnuEthernetBridgePortHistoryH\x00\x12\x31\n\nfecHistory\x18\x06 \x01(\x0b\x32\x1b.extension.GetOnuFecHistoryH\x00\x12\x36\n\nonuPonInfo\x18\x07 \x01(\x0b\x32 .extension.GetOnuCountersRequestH\x00\x12\x43\n\x07onuInfo\x18\x08 \x01(\x0b\x32\x30.extension.GetOmciEthernetFrameExtendedPmRequestH\x00\x12/\n\x07rxPower\x18\t \x01(\x0b\x32\x1c.extension.GetRxPowerRequestH\x00\x42\t\n\x07request\"\xa1\x07\n\x10GetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.GetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.GetValueResponse.ErrorReason\x12\x32\n\x08\x64istance\x18\x03 \x01(\x0b\x32\x1e.extension.GetDistanceResponseH\x00\x12\x33\n\x07uniInfo\x18\x04 \x01(\x0b\x32 .extension.GetOnuUniInfoResponseH\x00\x12=\n\x0cportCoutners\x18\x05 \x01(\x0b\x32%.extension.GetOltPortCountersResponseH\x00\x12\x41\n\x0eonuOpticalInfo\x18\x06 \x01(\x0b\x32\'.extension.GetOnuPonOpticalInfoResponseH\x00\x12O\n\x11\x65thBridgePortInfo\x18\x07 \x01(\x0b\x32\x32.extension.GetOnuEthernetBridgePortHistoryResponseH\x00\x12\x39\n\nfecHistory\x18\x08 \x01(\x0b\x32#.extension.GetOnuFecHistoryResponseH\x00\x12;\n\x0eonuPonCounters\x18\t \x01(\x0b\x32!.extension.GetOnuCountersResponseH\x00\x12H\n\x0bonuCounters\x18\n \x01(\x0b\x32\x31.extension.GetOmciEthernetFrameExtendedPmResponseH\x00\x12\x30\n\x07rxPower\x18\x0b \x01(\x0b\x32\x1d.extension.GetRxPowerResponseH\x00\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"\xad\x01\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\x12\x15\n\x11INVALID_DEVICE_ID\x10\x02\x12\x15\n\x11INVALID_PORT_TYPE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x14\n\x10INVALID_REQ_TYPE\x10\x05\x12\x12\n\x0eINTERNAL_ERROR\x10\x06\x12\x12\n\x0eINVALID_DEVICE\x10\x07\x42\n\n\x08response\"I\n\x0fSetValueRequest\x12+\n\x0c\x61larm_config\x18\x01 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x42\t\n\x07request\"\xeb\x01\n\x10SetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.SetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.SetValueResponse.ErrorReason\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"4\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\"V\n\x15SingleGetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.GetValueRequest\"G\n\x16SingleGetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.GetValueResponse\"V\n\x15SingleSetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.SetValueRequest\"G\n\x16SingleSetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.SetValueResponse2\xb3\x01\n\tExtension\x12R\n\x0bGetExtValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12R\n\x0bSetExtValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponseBR\n\x1dorg.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v5/go/extensionb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_ext__config__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_VALUETYPE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='extension.ValueType.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=197,
  serialized_end=228,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE_TYPE)

_GETONUUNIINFORESPONSE_CONFIGURATIONIND = _descriptor.EnumDescriptor(
  name='ConfigurationInd',
  full_name='extension.GetOnuUniInfoResponse.ConfigurationInd',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_BASE_T_FDX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUNDRED_BASE_T_FDX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIGABIT_ETHERNET_FDX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_G_ETHERNET_FDX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_BASE_T_HDX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUNDRED_BASE_T_HDX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIGABIT_ETHERNET_HDX', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=750,
  serialized_end=944,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_CONFIGURATIONIND)

_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE = _descriptor.EnumDescriptor(
  name='AdministrativeState',
  full_name='extension.GetOnuUniInfoResponse.AdministrativeState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADMSTATE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNLOCKED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=946,
  serialized_end=1017,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE)

_GETONUUNIINFORESPONSE_OPERATIONALSTATE = _descriptor.EnumDescriptor(
  name='OperationalState',
  full_name='extension.GetOnuUniInfoResponse.OperationalState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERSTATE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1019,
  serialized_end=1089,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_OPERATIONALSTATE)

_GETOLTPORTCOUNTERS_PORTTYPE = _descriptor.EnumDescriptor(
  name='PortType',
  full_name='extension.GetOltPortCounters.PortType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Port_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Port_ETHERNET_NNI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Port_PON_OLT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1188,
  serialized_end=1257,
)
_sym_db.RegisterEnumDescriptor(_GETOLTPORTCOUNTERS_PORTTYPE)

_GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='extension.GetOnuEthernetBridgePortHistory.Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPSTREAM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNSTREAM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1894,
  serialized_end=1950,
)
_sym_db.RegisterEnumDescriptor(_GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION)

_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='extension.GetOmciEthernetFrameExtendedPmResponse.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THIRTY_TWO_BIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIXTY_FOUR_BIT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4745,
  serialized_end=4793,
)
_sym_db.RegisterEnumDescriptor(_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT)

_GETVALUERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='extension.GetValueResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6139,
  serialized_end=6188,
)
_sym_db.RegisterEnumDescriptor(_GETVALUERESPONSE_STATUS)

_GETVALUERESPONSE_ERRORREASON = _descriptor.EnumDescriptor(
  name='ErrorReason',
  full_name='extension.GetValueResponse.ErrorReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DEVICE_ID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PORT_TYPE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REQ_TYPE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DEVICE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6191,
  serialized_end=6364,
)
_sym_db.RegisterEnumDescriptor(_GETVALUERESPONSE_ERRORREASON)

_SETVALUERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='extension.SetValueResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6139,
  serialized_end=6188,
)
_sym_db.RegisterEnumDescriptor(_SETVALUERESPONSE_STATUS)

_SETVALUERESPONSE_ERRORREASON = _descriptor.EnumDescriptor(
  name='ErrorReason',
  full_name='extension.SetValueResponse.ErrorReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6191,
  serialized_end=6243,
)
_sym_db.RegisterEnumDescriptor(_SETVALUERESPONSE_ERRORREASON)


_VALUESET = _descriptor.Descriptor(
  name='ValueSet',
  full_name='extension.ValueSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='extension.ValueSet.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm_config', full_name='extension.ValueSet.alarm_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='extension.ValueSet.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106,
  serialized_end=182,
)


_VALUETYPE = _descriptor.Descriptor(
  name='ValueType',
  full_name='extension.ValueType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VALUETYPE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=228,
)


_VALUESPECIFIER = _descriptor.Descriptor(
  name='ValueSpecifier',
  full_name='extension.ValueSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='extension.ValueSpecifier.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='extension.ValueSpecifier.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=300,
)


_RETURNVALUES = _descriptor.Descriptor(
  name='ReturnValues',
  full_name='extension.ReturnValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Set', full_name='extension.ReturnValues.Set', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Unsupported', full_name='extension.ReturnValues.Unsupported', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Error', full_name='extension.ReturnValues.Error', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Distance', full_name='extension.ReturnValues.Distance', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=383,
)


_GETDISTANCEREQUEST = _descriptor.Descriptor(
  name='GetDistanceRequest',
  full_name='extension.GetDistanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='onuDeviceId', full_name='extension.GetDistanceRequest.onuDeviceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=426,
)


_GETDISTANCERESPONSE = _descriptor.Descriptor(
  name='GetDistanceResponse',
  full_name='extension.GetDistanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetDistanceResponse.distance', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=467,
)


_GETONUUNIINFOREQUEST = _descriptor.Descriptor(
  name='GetOnuUniInfoRequest',
  full_name='extension.GetOnuUniInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uniIndex', full_name='extension.GetOnuUniInfoRequest.uniIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=509,
)


_GETONUUNIINFORESPONSE = _descriptor.Descriptor(
  name='GetOnuUniInfoResponse',
  full_name='extension.GetOnuUniInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='admState', full_name='extension.GetOnuUniInfoResponse.admState', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operState', full_name='extension.GetOnuUniInfoResponse.operState', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configInd', full_name='extension.GetOnuUniInfoResponse.configInd', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETONUUNIINFORESPONSE_CONFIGURATIONIND,
    _GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE,
    _GETONUUNIINFORESPONSE_OPERATIONALSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=1089,
)


_GETOLTPORTCOUNTERS = _descriptor.Descriptor(
  name='GetOltPortCounters',
  full_name='extension.GetOltPortCounters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='portNo', full_name='extension.GetOltPortCounters.portNo', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portType', full_name='extension.GetOltPortCounters.portType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETOLTPORTCOUNTERS_PORTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1257,
)


_GETOLTPORTCOUNTERSRESPONSE = _descriptor.Descriptor(
  name='GetOltPortCountersResponse',
  full_name='extension.GetOltPortCountersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txBytes', full_name='extension.GetOltPortCountersResponse.txBytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxBytes', full_name='extension.GetOltPortCountersResponse.rxBytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txPackets', full_name='extension.GetOltPortCountersResponse.txPackets', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxPackets', full_name='extension.GetOltPortCountersResponse.rxPackets', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txErrorPackets', full_name='extension.GetOltPortCountersResponse.txErrorPackets', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxErrorPackets', full_name='extension.GetOltPortCountersResponse.rxErrorPackets', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txBcastPackets', full_name='extension.GetOltPortCountersResponse.txBcastPackets', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxBcastPackets', full_name='extension.GetOltPortCountersResponse.rxBcastPackets', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txUcastPackets', full_name='extension.GetOltPortCountersResponse.txUcastPackets', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxUcastPackets', full_name='extension.GetOltPortCountersResponse.rxUcastPackets', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txMcastPackets', full_name='extension.GetOltPortCountersResponse.txMcastPackets', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxMcastPackets', full_name='extension.GetOltPortCountersResponse.rxMcastPackets', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1552,
)


_GETONUPONOPTICALINFO = _descriptor.Descriptor(
  name='GetOnuPonOpticalInfo',
  full_name='extension.GetOnuPonOpticalInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='empty', full_name='extension.GetOnuPonOpticalInfo.empty', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1615,
)


_GETONUPONOPTICALINFORESPONSE = _descriptor.Descriptor(
  name='GetOnuPonOpticalInfoResponse',
  full_name='extension.GetOnuPonOpticalInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='powerFeedVoltage', full_name='extension.GetOnuPonOpticalInfoResponse.powerFeedVoltage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receivedOpticalPower', full_name='extension.GetOnuPonOpticalInfoResponse.receivedOpticalPower', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meanOpticalLaunchPower', full_name='extension.GetOnuPonOpticalInfoResponse.meanOpticalLaunchPower', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='laserBiasCurrent', full_name='extension.GetOnuPonOpticalInfoResponse.laserBiasCurrent', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='extension.GetOnuPonOpticalInfoResponse.temperature', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=1783,
)


_GETONUETHERNETBRIDGEPORTHISTORY = _descriptor.Descriptor(
  name='GetOnuEthernetBridgePortHistory',
  full_name='extension.GetOnuEthernetBridgePortHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='extension.GetOnuEthernetBridgePortHistory.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1950,
)


_GETONUETHERNETBRIDGEPORTHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetOnuEthernetBridgePortHistoryResponse',
  full_name='extension.GetOnuEthernetBridgePortHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dropEvents', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.dropEvents', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.octets', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcastPackets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.broadcastPackets', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multicastPackets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.multicastPackets', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crcErroredPackets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.crcErroredPackets', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undersizePackets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.undersizePackets', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oversizePackets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.oversizePackets', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets64octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets64octets', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets65To127octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets65To127octets', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets128To255Octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets128To255Octets', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets256To511octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets256To511octets', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets512To1023octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets512To1023octets', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets1024To1518octets', full_name='extension.GetOnuEthernetBridgePortHistoryResponse.packets1024To1518octets', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1953,
  serialized_end=2359,
)


_GETONUFECHISTORY = _descriptor.Descriptor(
  name='GetOnuFecHistory',
  full_name='extension.GetOnuFecHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='empty', full_name='extension.GetOnuFecHistory.empty', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2361,
  serialized_end=2418,
)


_GETONUFECHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetOnuFecHistoryResponse',
  full_name='extension.GetOnuFecHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='correctedBytes', full_name='extension.GetOnuFecHistoryResponse.correctedBytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correctedCodeWords', full_name='extension.GetOnuFecHistoryResponse.correctedCodeWords', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fecSeconds', full_name='extension.GetOnuFecHistoryResponse.fecSeconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCodeWords', full_name='extension.GetOnuFecHistoryResponse.totalCodeWords', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncorrectableCodeWords', full_name='extension.GetOnuFecHistoryResponse.uncorrectableCodeWords', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2421,
  serialized_end=2575,
)


_GETONUCOUNTERSREQUEST = _descriptor.Descriptor(
  name='GetOnuCountersRequest',
  full_name='extension.GetOnuCountersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='extension.GetOnuCountersRequest.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='extension.GetOnuCountersRequest.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2577,
  serialized_end=2633,
)


_GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST = _descriptor.Descriptor(
  name='GetOmciEthernetFrameExtendedPmRequest',
  full_name='extension.GetOmciEthernetFrameExtendedPmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='onuDeviceId', full_name='extension.GetOmciEthernetFrameExtendedPmRequest.onuDeviceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniIndex', full_name='extension.GetOmciEthernetFrameExtendedPmRequest.uniIndex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset', full_name='extension.GetOmciEthernetFrameExtendedPmRequest.reset', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='is_uni_index', full_name='extension.GetOmciEthernetFrameExtendedPmRequest.is_uni_index',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2635,
  serialized_end=2746,
)


_GETRXPOWERREQUEST = _descriptor.Descriptor(
  name='GetRxPowerRequest',
  full_name='extension.GetRxPowerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='extension.GetRxPowerRequest.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='extension.GetRxPowerRequest.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2748,
  serialized_end=2800,
)


_GETONUCOUNTERSRESPONSE = _descriptor.Descriptor(
  name='GetOnuCountersResponse',
  full_name='extension.GetOnuCountersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='extension.GetOnuCountersResponse.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='extension.GetOnuCountersResponse.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_drift', full_name='extension.GetOnuCountersResponse.positive_drift', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_drift', full_name='extension.GetOnuCountersResponse.negative_drift', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delimiter_miss_detection', full_name='extension.GetOnuCountersResponse.delimiter_miss_detection', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bip_errors', full_name='extension.GetOnuCountersResponse.bip_errors', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bip_units', full_name='extension.GetOnuCountersResponse.bip_units', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fec_corrected_symbols', full_name='extension.GetOnuCountersResponse.fec_corrected_symbols', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fec_codewords_corrected', full_name='extension.GetOnuCountersResponse.fec_codewords_corrected', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fec_codewords_uncorrectable', full_name='extension.GetOnuCountersResponse.fec_codewords_uncorrectable', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fec_codewords', full_name='extension.GetOnuCountersResponse.fec_codewords', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fec_corrected_units', full_name='extension.GetOnuCountersResponse.fec_corrected_units', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xgem_key_errors', full_name='extension.GetOnuCountersResponse.xgem_key_errors', index=12,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xgem_loss', full_name='extension.GetOnuCountersResponse.xgem_loss', index=13,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_ploams_error', full_name='extension.GetOnuCountersResponse.rx_ploams_error', index=14,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_ploams_non_idle', full_name='extension.GetOnuCountersResponse.rx_ploams_non_idle', index=15,
      number=16, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_omci', full_name='extension.GetOnuCountersResponse.rx_omci', index=16,
      number=17, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_omci', full_name='extension.GetOnuCountersResponse.tx_omci', index=17,
      number=18, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_omci_packets_crc_error', full_name='extension.GetOnuCountersResponse.rx_omci_packets_crc_error', index=18,
      number=19, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='extension.GetOnuCountersResponse.rx_bytes', index=19,
      number=20, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='extension.GetOnuCountersResponse.rx_packets', index=20,
      number=21, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='extension.GetOnuCountersResponse.tx_bytes', index=21,
      number=22, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='extension.GetOnuCountersResponse.tx_packets', index=22,
      number=23, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ber_reported', full_name='extension.GetOnuCountersResponse.ber_reported', index=23,
      number=24, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lcdg_errors', full_name='extension.GetOnuCountersResponse.lcdg_errors', index=24,
      number=25, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rdi_errors', full_name='extension.GetOnuCountersResponse.rdi_errors', index=25,
      number=26, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='extension.GetOnuCountersResponse.timestamp', index=26,
      number=27, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='is_intf_id', full_name='extension.GetOnuCountersResponse.is_intf_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_onu_id', full_name='extension.GetOnuCountersResponse.is_onu_id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_positive_drift', full_name='extension.GetOnuCountersResponse.is_positive_drift',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_negative_drift', full_name='extension.GetOnuCountersResponse.is_negative_drift',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_delimiter_miss_detection', full_name='extension.GetOnuCountersResponse.is_delimiter_miss_detection',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_bip_errors', full_name='extension.GetOnuCountersResponse.is_bip_errors',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_bip_units', full_name='extension.GetOnuCountersResponse.is_bip_units',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_fec_corrected_symbols', full_name='extension.GetOnuCountersResponse.is_fec_corrected_symbols',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_fec_codewords_corrected', full_name='extension.GetOnuCountersResponse.is_fec_codewords_corrected',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_fec_codewords_uncorrectable', full_name='extension.GetOnuCountersResponse.is_fec_codewords_uncorrectable',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_fec_codewords', full_name='extension.GetOnuCountersResponse.is_fec_codewords',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_fec_corrected_units', full_name='extension.GetOnuCountersResponse.is_fec_corrected_units',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_xgem_key_errors', full_name='extension.GetOnuCountersResponse.is_xgem_key_errors',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_xgem_loss', full_name='extension.GetOnuCountersResponse.is_xgem_loss',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_ploams_error', full_name='extension.GetOnuCountersResponse.is_rx_ploams_error',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_ploams_non_idle', full_name='extension.GetOnuCountersResponse.is_rx_ploams_non_idle',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_omci', full_name='extension.GetOnuCountersResponse.is_rx_omci',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_tx_omci', full_name='extension.GetOnuCountersResponse.is_tx_omci',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_omci_packets_crc_error', full_name='extension.GetOnuCountersResponse.is_rx_omci_packets_crc_error',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_bytes', full_name='extension.GetOnuCountersResponse.is_rx_bytes',
      index=19, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rx_packets', full_name='extension.GetOnuCountersResponse.is_rx_packets',
      index=20, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_tx_bytes', full_name='extension.GetOnuCountersResponse.is_tx_bytes',
      index=21, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_tx_packets', full_name='extension.GetOnuCountersResponse.is_tx_packets',
      index=22, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_ber_reported', full_name='extension.GetOnuCountersResponse.is_ber_reported',
      index=23, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_lcdg_errors', full_name='extension.GetOnuCountersResponse.is_lcdg_errors',
      index=24, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_rdi_errors', full_name='extension.GetOnuCountersResponse.is_rdi_errors',
      index=25, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='is_timestamp', full_name='extension.GetOnuCountersResponse.is_timestamp',
      index=26, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2803,
  serialized_end=4062,
)


_OMCIETHERNETFRAMEEXTENDEDPM = _descriptor.Descriptor(
  name='OmciEthernetFrameExtendedPm',
  full_name='extension.OmciEthernetFrameExtendedPm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_events', full_name='extension.OmciEthernetFrameExtendedPm.drop_events', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='octets', full_name='extension.OmciEthernetFrameExtendedPm.octets', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames', full_name='extension.OmciEthernetFrameExtendedPm.frames', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_frames', full_name='extension.OmciEthernetFrameExtendedPm.broadcast_frames', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multicast_frames', full_name='extension.OmciEthernetFrameExtendedPm.multicast_frames', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_errored_frames', full_name='extension.OmciEthernetFrameExtendedPm.crc_errored_frames', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undersize_frames', full_name='extension.OmciEthernetFrameExtendedPm.undersize_frames', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oversize_frames', full_name='extension.OmciEthernetFrameExtendedPm.oversize_frames', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_64_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_64_octets', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_65_to_127_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_65_to_127_octets', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_128_to_255_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_128_to_255_octets', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_256_to_511_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_256_to_511_octets', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_512_to_1023_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_512_to_1023_octets', index=12,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_1024_to_1518_octets', full_name='extension.OmciEthernetFrameExtendedPm.frames_1024_to_1518_octets', index=13,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4065,
  serialized_end=4476,
)


_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE = _descriptor.Descriptor(
  name='GetOmciEthernetFrameExtendedPmResponse',
  full_name='extension.GetOmciEthernetFrameExtendedPmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upstream', full_name='extension.GetOmciEthernetFrameExtendedPmResponse.upstream', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream', full_name='extension.GetOmciEthernetFrameExtendedPmResponse.downstream', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omci_ethernet_frame_extended_pm_format', full_name='extension.GetOmciEthernetFrameExtendedPmResponse.omci_ethernet_frame_extended_pm_format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4479,
  serialized_end=4793,
)


_GETRXPOWERRESPONSE = _descriptor.Descriptor(
  name='GetRxPowerResponse',
  full_name='extension.GetRxPowerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='extension.GetRxPowerResponse.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='extension.GetRxPowerResponse.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='extension.GetRxPowerResponse.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_reason', full_name='extension.GetRxPowerResponse.fail_reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_power', full_name='extension.GetRxPowerResponse.rx_power', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4795,
  serialized_end=4903,
)


_GETVALUEREQUEST = _descriptor.Descriptor(
  name='GetValueRequest',
  full_name='extension.GetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetValueRequest.distance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniInfo', full_name='extension.GetValueRequest.uniInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oltPortInfo', full_name='extension.GetValueRequest.oltPortInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuOpticalInfo', full_name='extension.GetValueRequest.onuOpticalInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethBridgePort', full_name='extension.GetValueRequest.ethBridgePort', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fecHistory', full_name='extension.GetValueRequest.fecHistory', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuPonInfo', full_name='extension.GetValueRequest.onuPonInfo', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuInfo', full_name='extension.GetValueRequest.onuInfo', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxPower', full_name='extension.GetValueRequest.rxPower', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='extension.GetValueRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4906,
  serialized_end=5444,
)


_GETVALUERESPONSE = _descriptor.Descriptor(
  name='GetValueResponse',
  full_name='extension.GetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='extension.GetValueResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errReason', full_name='extension.GetValueResponse.errReason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetValueResponse.distance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniInfo', full_name='extension.GetValueResponse.uniInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portCoutners', full_name='extension.GetValueResponse.portCoutners', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuOpticalInfo', full_name='extension.GetValueResponse.onuOpticalInfo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethBridgePortInfo', full_name='extension.GetValueResponse.ethBridgePortInfo', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fecHistory', full_name='extension.GetValueResponse.fecHistory', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuPonCounters', full_name='extension.GetValueResponse.onuPonCounters', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuCounters', full_name='extension.GetValueResponse.onuCounters', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxPower', full_name='extension.GetValueResponse.rxPower', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETVALUERESPONSE_STATUS,
    _GETVALUERESPONSE_ERRORREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='extension.GetValueResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5447,
  serialized_end=6376,
)


_SETVALUEREQUEST = _descriptor.Descriptor(
  name='SetValueRequest',
  full_name='extension.SetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarm_config', full_name='extension.SetValueRequest.alarm_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='extension.SetValueRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6378,
  serialized_end=6451,
)


_SETVALUERESPONSE = _descriptor.Descriptor(
  name='SetValueResponse',
  full_name='extension.SetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='extension.SetValueResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errReason', full_name='extension.SetValueResponse.errReason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETVALUERESPONSE_STATUS,
    _SETVALUERESPONSE_ERRORREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6454,
  serialized_end=6689,
)


_SINGLEGETVALUEREQUEST = _descriptor.Descriptor(
  name='SingleGetValueRequest',
  full_name='extension.SingleGetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetId', full_name='extension.SingleGetValueRequest.targetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='extension.SingleGetValueRequest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6691,
  serialized_end=6777,
)


_SINGLEGETVALUERESPONSE = _descriptor.Descriptor(
  name='SingleGetValueResponse',
  full_name='extension.SingleGetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='extension.SingleGetValueResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6779,
  serialized_end=6850,
)


_SINGLESETVALUEREQUEST = _descriptor.Descriptor(
  name='SingleSetValueRequest',
  full_name='extension.SingleSetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetId', full_name='extension.SingleSetValueRequest.targetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='extension.SingleSetValueRequest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6852,
  serialized_end=6938,
)


_SINGLESETVALUERESPONSE = _descriptor.Descriptor(
  name='SingleSetValueResponse',
  full_name='extension.SingleSetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='extension.SingleSetValueResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6940,
  serialized_end=7011,
)

_VALUESET.fields_by_name['alarm_config'].message_type = voltha__protos_dot_ext__config__pb2._ALARMCONFIG
_VALUESET.oneofs_by_name['value'].fields.append(
  _VALUESET.fields_by_name['alarm_config'])
_VALUESET.fields_by_name['alarm_config'].containing_oneof = _VALUESET.oneofs_by_name['value']
_VALUETYPE_TYPE.containing_type = _VALUETYPE
_VALUESPECIFIER.fields_by_name['value'].enum_type = _VALUETYPE_TYPE
_GETONUUNIINFORESPONSE.fields_by_name['admState'].enum_type = _GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE
_GETONUUNIINFORESPONSE.fields_by_name['operState'].enum_type = _GETONUUNIINFORESPONSE_OPERATIONALSTATE
_GETONUUNIINFORESPONSE.fields_by_name['configInd'].enum_type = _GETONUUNIINFORESPONSE_CONFIGURATIONIND
_GETONUUNIINFORESPONSE_CONFIGURATIONIND.containing_type = _GETONUUNIINFORESPONSE
_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE.containing_type = _GETONUUNIINFORESPONSE
_GETONUUNIINFORESPONSE_OPERATIONALSTATE.containing_type = _GETONUUNIINFORESPONSE
_GETOLTPORTCOUNTERS.fields_by_name['portType'].enum_type = _GETOLTPORTCOUNTERS_PORTTYPE
_GETOLTPORTCOUNTERS_PORTTYPE.containing_type = _GETOLTPORTCOUNTERS
_GETONUPONOPTICALINFO.fields_by_name['empty'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GETONUETHERNETBRIDGEPORTHISTORY.fields_by_name['direction'].enum_type = _GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION
_GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION.containing_type = _GETONUETHERNETBRIDGEPORTHISTORY
_GETONUFECHISTORY.fields_by_name['empty'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST.oneofs_by_name['is_uni_index'].fields.append(
  _GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST.fields_by_name['uniIndex'])
_GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST.fields_by_name['uniIndex'].containing_oneof = _GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST.oneofs_by_name['is_uni_index']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_intf_id'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['intf_id'])
_GETONUCOUNTERSRESPONSE.fields_by_name['intf_id'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_intf_id']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_onu_id'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['onu_id'])
_GETONUCOUNTERSRESPONSE.fields_by_name['onu_id'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_onu_id']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_positive_drift'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['positive_drift'])
_GETONUCOUNTERSRESPONSE.fields_by_name['positive_drift'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_positive_drift']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_negative_drift'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['negative_drift'])
_GETONUCOUNTERSRESPONSE.fields_by_name['negative_drift'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_negative_drift']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_delimiter_miss_detection'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['delimiter_miss_detection'])
_GETONUCOUNTERSRESPONSE.fields_by_name['delimiter_miss_detection'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_delimiter_miss_detection']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_bip_errors'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['bip_errors'])
_GETONUCOUNTERSRESPONSE.fields_by_name['bip_errors'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_bip_errors']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_bip_units'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['bip_units'])
_GETONUCOUNTERSRESPONSE.fields_by_name['bip_units'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_bip_units']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_corrected_symbols'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['fec_corrected_symbols'])
_GETONUCOUNTERSRESPONSE.fields_by_name['fec_corrected_symbols'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_corrected_symbols']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords_corrected'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords_corrected'])
_GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords_corrected'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords_corrected']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords_uncorrectable'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords_uncorrectable'])
_GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords_uncorrectable'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords_uncorrectable']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords'])
_GETONUCOUNTERSRESPONSE.fields_by_name['fec_codewords'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_codewords']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_corrected_units'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['fec_corrected_units'])
_GETONUCOUNTERSRESPONSE.fields_by_name['fec_corrected_units'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_fec_corrected_units']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_xgem_key_errors'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['xgem_key_errors'])
_GETONUCOUNTERSRESPONSE.fields_by_name['xgem_key_errors'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_xgem_key_errors']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_xgem_loss'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['xgem_loss'])
_GETONUCOUNTERSRESPONSE.fields_by_name['xgem_loss'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_xgem_loss']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_ploams_error'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_ploams_error'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_ploams_error'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_ploams_error']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_ploams_non_idle'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_ploams_non_idle'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_ploams_non_idle'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_ploams_non_idle']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_omci'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_omci'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_omci'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_omci']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_omci'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['tx_omci'])
_GETONUCOUNTERSRESPONSE.fields_by_name['tx_omci'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_omci']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_omci_packets_crc_error'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_omci_packets_crc_error'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_omci_packets_crc_error'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_omci_packets_crc_error']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_bytes'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_bytes'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_bytes'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_bytes']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_packets'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rx_packets'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rx_packets'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rx_packets']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_bytes'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['tx_bytes'])
_GETONUCOUNTERSRESPONSE.fields_by_name['tx_bytes'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_bytes']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_packets'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['tx_packets'])
_GETONUCOUNTERSRESPONSE.fields_by_name['tx_packets'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_tx_packets']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_ber_reported'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['ber_reported'])
_GETONUCOUNTERSRESPONSE.fields_by_name['ber_reported'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_ber_reported']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_lcdg_errors'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['lcdg_errors'])
_GETONUCOUNTERSRESPONSE.fields_by_name['lcdg_errors'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_lcdg_errors']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rdi_errors'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['rdi_errors'])
_GETONUCOUNTERSRESPONSE.fields_by_name['rdi_errors'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_rdi_errors']
_GETONUCOUNTERSRESPONSE.oneofs_by_name['is_timestamp'].fields.append(
  _GETONUCOUNTERSRESPONSE.fields_by_name['timestamp'])
_GETONUCOUNTERSRESPONSE.fields_by_name['timestamp'].containing_oneof = _GETONUCOUNTERSRESPONSE.oneofs_by_name['is_timestamp']
_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE.fields_by_name['upstream'].message_type = _OMCIETHERNETFRAMEEXTENDEDPM
_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE.fields_by_name['downstream'].message_type = _OMCIETHERNETFRAMEEXTENDEDPM
_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE.fields_by_name['omci_ethernet_frame_extended_pm_format'].enum_type = _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT
_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT.containing_type = _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE
_GETVALUEREQUEST.fields_by_name['distance'].message_type = _GETDISTANCEREQUEST
_GETVALUEREQUEST.fields_by_name['uniInfo'].message_type = _GETONUUNIINFOREQUEST
_GETVALUEREQUEST.fields_by_name['oltPortInfo'].message_type = _GETOLTPORTCOUNTERS
_GETVALUEREQUEST.fields_by_name['onuOpticalInfo'].message_type = _GETONUPONOPTICALINFO
_GETVALUEREQUEST.fields_by_name['ethBridgePort'].message_type = _GETONUETHERNETBRIDGEPORTHISTORY
_GETVALUEREQUEST.fields_by_name['fecHistory'].message_type = _GETONUFECHISTORY
_GETVALUEREQUEST.fields_by_name['onuPonInfo'].message_type = _GETONUCOUNTERSREQUEST
_GETVALUEREQUEST.fields_by_name['onuInfo'].message_type = _GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST
_GETVALUEREQUEST.fields_by_name['rxPower'].message_type = _GETRXPOWERREQUEST
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['distance'])
_GETVALUEREQUEST.fields_by_name['distance'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['uniInfo'])
_GETVALUEREQUEST.fields_by_name['uniInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['oltPortInfo'])
_GETVALUEREQUEST.fields_by_name['oltPortInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['onuOpticalInfo'])
_GETVALUEREQUEST.fields_by_name['onuOpticalInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['ethBridgePort'])
_GETVALUEREQUEST.fields_by_name['ethBridgePort'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['fecHistory'])
_GETVALUEREQUEST.fields_by_name['fecHistory'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['onuPonInfo'])
_GETVALUEREQUEST.fields_by_name['onuPonInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['onuInfo'])
_GETVALUEREQUEST.fields_by_name['onuInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['rxPower'])
_GETVALUEREQUEST.fields_by_name['rxPower'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUERESPONSE.fields_by_name['status'].enum_type = _GETVALUERESPONSE_STATUS
_GETVALUERESPONSE.fields_by_name['errReason'].enum_type = _GETVALUERESPONSE_ERRORREASON
_GETVALUERESPONSE.fields_by_name['distance'].message_type = _GETDISTANCERESPONSE
_GETVALUERESPONSE.fields_by_name['uniInfo'].message_type = _GETONUUNIINFORESPONSE
_GETVALUERESPONSE.fields_by_name['portCoutners'].message_type = _GETOLTPORTCOUNTERSRESPONSE
_GETVALUERESPONSE.fields_by_name['onuOpticalInfo'].message_type = _GETONUPONOPTICALINFORESPONSE
_GETVALUERESPONSE.fields_by_name['ethBridgePortInfo'].message_type = _GETONUETHERNETBRIDGEPORTHISTORYRESPONSE
_GETVALUERESPONSE.fields_by_name['fecHistory'].message_type = _GETONUFECHISTORYRESPONSE
_GETVALUERESPONSE.fields_by_name['onuPonCounters'].message_type = _GETONUCOUNTERSRESPONSE
_GETVALUERESPONSE.fields_by_name['onuCounters'].message_type = _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE
_GETVALUERESPONSE.fields_by_name['rxPower'].message_type = _GETRXPOWERRESPONSE
_GETVALUERESPONSE_STATUS.containing_type = _GETVALUERESPONSE
_GETVALUERESPONSE_ERRORREASON.containing_type = _GETVALUERESPONSE
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['distance'])
_GETVALUERESPONSE.fields_by_name['distance'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['uniInfo'])
_GETVALUERESPONSE.fields_by_name['uniInfo'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['portCoutners'])
_GETVALUERESPONSE.fields_by_name['portCoutners'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['onuOpticalInfo'])
_GETVALUERESPONSE.fields_by_name['onuOpticalInfo'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['ethBridgePortInfo'])
_GETVALUERESPONSE.fields_by_name['ethBridgePortInfo'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['fecHistory'])
_GETVALUERESPONSE.fields_by_name['fecHistory'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['onuPonCounters'])
_GETVALUERESPONSE.fields_by_name['onuPonCounters'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['onuCounters'])
_GETVALUERESPONSE.fields_by_name['onuCounters'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['rxPower'])
_GETVALUERESPONSE.fields_by_name['rxPower'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_SETVALUEREQUEST.fields_by_name['alarm_config'].message_type = voltha__protos_dot_ext__config__pb2._ALARMCONFIG
_SETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _SETVALUEREQUEST.fields_by_name['alarm_config'])
_SETVALUEREQUEST.fields_by_name['alarm_config'].containing_oneof = _SETVALUEREQUEST.oneofs_by_name['request']
_SETVALUERESPONSE.fields_by_name['status'].enum_type = _SETVALUERESPONSE_STATUS
_SETVALUERESPONSE.fields_by_name['errReason'].enum_type = _SETVALUERESPONSE_ERRORREASON
_SETVALUERESPONSE_STATUS.containing_type = _SETVALUERESPONSE
_SETVALUERESPONSE_ERRORREASON.containing_type = _SETVALUERESPONSE
_SINGLEGETVALUEREQUEST.fields_by_name['request'].message_type = _GETVALUEREQUEST
_SINGLEGETVALUERESPONSE.fields_by_name['response'].message_type = _GETVALUERESPONSE
_SINGLESETVALUEREQUEST.fields_by_name['request'].message_type = _SETVALUEREQUEST
_SINGLESETVALUERESPONSE.fields_by_name['response'].message_type = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['ValueSet'] = _VALUESET
DESCRIPTOR.message_types_by_name['ValueType'] = _VALUETYPE
DESCRIPTOR.message_types_by_name['ValueSpecifier'] = _VALUESPECIFIER
DESCRIPTOR.message_types_by_name['ReturnValues'] = _RETURNVALUES
DESCRIPTOR.message_types_by_name['GetDistanceRequest'] = _GETDISTANCEREQUEST
DESCRIPTOR.message_types_by_name['GetDistanceResponse'] = _GETDISTANCERESPONSE
DESCRIPTOR.message_types_by_name['GetOnuUniInfoRequest'] = _GETONUUNIINFOREQUEST
DESCRIPTOR.message_types_by_name['GetOnuUniInfoResponse'] = _GETONUUNIINFORESPONSE
DESCRIPTOR.message_types_by_name['GetOltPortCounters'] = _GETOLTPORTCOUNTERS
DESCRIPTOR.message_types_by_name['GetOltPortCountersResponse'] = _GETOLTPORTCOUNTERSRESPONSE
DESCRIPTOR.message_types_by_name['GetOnuPonOpticalInfo'] = _GETONUPONOPTICALINFO
DESCRIPTOR.message_types_by_name['GetOnuPonOpticalInfoResponse'] = _GETONUPONOPTICALINFORESPONSE
DESCRIPTOR.message_types_by_name['GetOnuEthernetBridgePortHistory'] = _GETONUETHERNETBRIDGEPORTHISTORY
DESCRIPTOR.message_types_by_name['GetOnuEthernetBridgePortHistoryResponse'] = _GETONUETHERNETBRIDGEPORTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetOnuFecHistory'] = _GETONUFECHISTORY
DESCRIPTOR.message_types_by_name['GetOnuFecHistoryResponse'] = _GETONUFECHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetOnuCountersRequest'] = _GETONUCOUNTERSREQUEST
DESCRIPTOR.message_types_by_name['GetOmciEthernetFrameExtendedPmRequest'] = _GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST
DESCRIPTOR.message_types_by_name['GetRxPowerRequest'] = _GETRXPOWERREQUEST
DESCRIPTOR.message_types_by_name['GetOnuCountersResponse'] = _GETONUCOUNTERSRESPONSE
DESCRIPTOR.message_types_by_name['OmciEthernetFrameExtendedPm'] = _OMCIETHERNETFRAMEEXTENDEDPM
DESCRIPTOR.message_types_by_name['GetOmciEthernetFrameExtendedPmResponse'] = _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE
DESCRIPTOR.message_types_by_name['GetRxPowerResponse'] = _GETRXPOWERRESPONSE
DESCRIPTOR.message_types_by_name['GetValueRequest'] = _GETVALUEREQUEST
DESCRIPTOR.message_types_by_name['GetValueResponse'] = _GETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SetValueRequest'] = _SETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetValueResponse'] = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SingleGetValueRequest'] = _SINGLEGETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SingleGetValueResponse'] = _SINGLEGETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SingleSetValueRequest'] = _SINGLESETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SingleSetValueResponse'] = _SINGLESETVALUERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValueSet = _reflection.GeneratedProtocolMessageType('ValueSet', (_message.Message,), {
  'DESCRIPTOR' : _VALUESET,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.ValueSet)
  })
_sym_db.RegisterMessage(ValueSet)

ValueType = _reflection.GeneratedProtocolMessageType('ValueType', (_message.Message,), {
  'DESCRIPTOR' : _VALUETYPE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.ValueType)
  })
_sym_db.RegisterMessage(ValueType)

ValueSpecifier = _reflection.GeneratedProtocolMessageType('ValueSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _VALUESPECIFIER,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.ValueSpecifier)
  })
_sym_db.RegisterMessage(ValueSpecifier)

ReturnValues = _reflection.GeneratedProtocolMessageType('ReturnValues', (_message.Message,), {
  'DESCRIPTOR' : _RETURNVALUES,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.ReturnValues)
  })
_sym_db.RegisterMessage(ReturnValues)

GetDistanceRequest = _reflection.GeneratedProtocolMessageType('GetDistanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISTANCEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetDistanceRequest)
  })
_sym_db.RegisterMessage(GetDistanceRequest)

GetDistanceResponse = _reflection.GeneratedProtocolMessageType('GetDistanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDISTANCERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetDistanceResponse)
  })
_sym_db.RegisterMessage(GetDistanceResponse)

GetOnuUniInfoRequest = _reflection.GeneratedProtocolMessageType('GetOnuUniInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETONUUNIINFOREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuUniInfoRequest)
  })
_sym_db.RegisterMessage(GetOnuUniInfoRequest)

GetOnuUniInfoResponse = _reflection.GeneratedProtocolMessageType('GetOnuUniInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUUNIINFORESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuUniInfoResponse)
  })
_sym_db.RegisterMessage(GetOnuUniInfoResponse)

GetOltPortCounters = _reflection.GeneratedProtocolMessageType('GetOltPortCounters', (_message.Message,), {
  'DESCRIPTOR' : _GETOLTPORTCOUNTERS,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOltPortCounters)
  })
_sym_db.RegisterMessage(GetOltPortCounters)

GetOltPortCountersResponse = _reflection.GeneratedProtocolMessageType('GetOltPortCountersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOLTPORTCOUNTERSRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOltPortCountersResponse)
  })
_sym_db.RegisterMessage(GetOltPortCountersResponse)

GetOnuPonOpticalInfo = _reflection.GeneratedProtocolMessageType('GetOnuPonOpticalInfo', (_message.Message,), {
  'DESCRIPTOR' : _GETONUPONOPTICALINFO,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuPonOpticalInfo)
  })
_sym_db.RegisterMessage(GetOnuPonOpticalInfo)

GetOnuPonOpticalInfoResponse = _reflection.GeneratedProtocolMessageType('GetOnuPonOpticalInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUPONOPTICALINFORESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuPonOpticalInfoResponse)
  })
_sym_db.RegisterMessage(GetOnuPonOpticalInfoResponse)

GetOnuEthernetBridgePortHistory = _reflection.GeneratedProtocolMessageType('GetOnuEthernetBridgePortHistory', (_message.Message,), {
  'DESCRIPTOR' : _GETONUETHERNETBRIDGEPORTHISTORY,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuEthernetBridgePortHistory)
  })
_sym_db.RegisterMessage(GetOnuEthernetBridgePortHistory)

GetOnuEthernetBridgePortHistoryResponse = _reflection.GeneratedProtocolMessageType('GetOnuEthernetBridgePortHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUETHERNETBRIDGEPORTHISTORYRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuEthernetBridgePortHistoryResponse)
  })
_sym_db.RegisterMessage(GetOnuEthernetBridgePortHistoryResponse)

GetOnuFecHistory = _reflection.GeneratedProtocolMessageType('GetOnuFecHistory', (_message.Message,), {
  'DESCRIPTOR' : _GETONUFECHISTORY,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuFecHistory)
  })
_sym_db.RegisterMessage(GetOnuFecHistory)

GetOnuFecHistoryResponse = _reflection.GeneratedProtocolMessageType('GetOnuFecHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUFECHISTORYRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuFecHistoryResponse)
  })
_sym_db.RegisterMessage(GetOnuFecHistoryResponse)

GetOnuCountersRequest = _reflection.GeneratedProtocolMessageType('GetOnuCountersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETONUCOUNTERSREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuCountersRequest)
  })
_sym_db.RegisterMessage(GetOnuCountersRequest)

GetOmciEthernetFrameExtendedPmRequest = _reflection.GeneratedProtocolMessageType('GetOmciEthernetFrameExtendedPmRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOmciEthernetFrameExtendedPmRequest)
  })
_sym_db.RegisterMessage(GetOmciEthernetFrameExtendedPmRequest)

GetRxPowerRequest = _reflection.GeneratedProtocolMessageType('GetRxPowerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRXPOWERREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetRxPowerRequest)
  })
_sym_db.RegisterMessage(GetRxPowerRequest)

GetOnuCountersResponse = _reflection.GeneratedProtocolMessageType('GetOnuCountersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUCOUNTERSRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuCountersResponse)
  })
_sym_db.RegisterMessage(GetOnuCountersResponse)

OmciEthernetFrameExtendedPm = _reflection.GeneratedProtocolMessageType('OmciEthernetFrameExtendedPm', (_message.Message,), {
  'DESCRIPTOR' : _OMCIETHERNETFRAMEEXTENDEDPM,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.OmciEthernetFrameExtendedPm)
  })
_sym_db.RegisterMessage(OmciEthernetFrameExtendedPm)

GetOmciEthernetFrameExtendedPmResponse = _reflection.GeneratedProtocolMessageType('GetOmciEthernetFrameExtendedPmResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOmciEthernetFrameExtendedPmResponse)
  })
_sym_db.RegisterMessage(GetOmciEthernetFrameExtendedPmResponse)

GetRxPowerResponse = _reflection.GeneratedProtocolMessageType('GetRxPowerResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRXPOWERRESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetRxPowerResponse)
  })
_sym_db.RegisterMessage(GetRxPowerResponse)

GetValueRequest = _reflection.GeneratedProtocolMessageType('GetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetValueRequest)
  })
_sym_db.RegisterMessage(GetValueRequest)

GetValueResponse = _reflection.GeneratedProtocolMessageType('GetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetValueResponse)
  })
_sym_db.RegisterMessage(GetValueResponse)

SetValueRequest = _reflection.GeneratedProtocolMessageType('SetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SetValueRequest)
  })
_sym_db.RegisterMessage(SetValueRequest)

SetValueResponse = _reflection.GeneratedProtocolMessageType('SetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SetValueResponse)
  })
_sym_db.RegisterMessage(SetValueResponse)

SingleGetValueRequest = _reflection.GeneratedProtocolMessageType('SingleGetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEGETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleGetValueRequest)
  })
_sym_db.RegisterMessage(SingleGetValueRequest)

SingleGetValueResponse = _reflection.GeneratedProtocolMessageType('SingleGetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEGETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleGetValueResponse)
  })
_sym_db.RegisterMessage(SingleGetValueResponse)

SingleSetValueRequest = _reflection.GeneratedProtocolMessageType('SingleSetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SINGLESETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleSetValueRequest)
  })
_sym_db.RegisterMessage(SingleSetValueRequest)

SingleSetValueResponse = _reflection.GeneratedProtocolMessageType('SingleSetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SINGLESETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleSetValueResponse)
  })
_sym_db.RegisterMessage(SingleSetValueResponse)


DESCRIPTOR._options = None

_EXTENSION = _descriptor.ServiceDescriptor(
  name='Extension',
  full_name='extension.Extension',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7014,
  serialized_end=7193,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='extension.Extension.GetExtValue',
    index=0,
    containing_service=None,
    input_type=_SINGLEGETVALUEREQUEST,
    output_type=_SINGLEGETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='extension.Extension.SetExtValue',
    index=1,
    containing_service=None,
    input_type=_SINGLESETVALUEREQUEST,
    output_type=_SINGLESETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSION)

DESCRIPTOR.services_by_name['Extension'] = _EXTENSION

# @@protoc_insertion_point(module_scope)
